# coding: utf-8

"""
    ExaVault API

    See our API reference documentation at https://www.exavault.com/developer/api-docs/  # noqa: E501

    OpenAPI spec version: 2.0
    Contact: support@exavault.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class FormAttributes(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'form_description': 'str',
        'submit_button_text': 'str',
        'success_message': 'str',
        'css_styles': 'str',
        'elements': 'list[FormField]'
    }

    attribute_map = {
        'form_description': 'formDescription',
        'submit_button_text': 'submitButtonText',
        'success_message': 'successMessage',
        'css_styles': 'cssStyles',
        'elements': 'elements'
    }

    def __init__(self, form_description=None, submit_button_text=None, success_message=None, css_styles=None, elements=None):  # noqa: E501
        """FormAttributes - a model defined in Swagger"""  # noqa: E501
        self._form_description = None
        self._submit_button_text = None
        self._success_message = None
        self._css_styles = None
        self._elements = None
        self.discriminator = None
        if form_description is not None:
            self.form_description = form_description
        if submit_button_text is not None:
            self.submit_button_text = submit_button_text
        if success_message is not None:
            self.success_message = success_message
        if css_styles is not None:
            self.css_styles = css_styles
        if elements is not None:
            self.elements = elements

    @property
    def form_description(self):
        """Gets the form_description of this FormAttributes.  # noqa: E501

        Text that appears at the top of a receive form  # noqa: E501

        :return: The form_description of this FormAttributes.  # noqa: E501
        :rtype: str
        """
        return self._form_description

    @form_description.setter
    def form_description(self, form_description):
        """Sets the form_description of this FormAttributes.

        Text that appears at the top of a receive form  # noqa: E501

        :param form_description: The form_description of this FormAttributes.  # noqa: E501
        :type: str
        """

        self._form_description = form_description

    @property
    def submit_button_text(self):
        """Gets the submit_button_text of this FormAttributes.  # noqa: E501

        Text that appears on the submit button for the form  # noqa: E501

        :return: The submit_button_text of this FormAttributes.  # noqa: E501
        :rtype: str
        """
        return self._submit_button_text

    @submit_button_text.setter
    def submit_button_text(self, submit_button_text):
        """Sets the submit_button_text of this FormAttributes.

        Text that appears on the submit button for the form  # noqa: E501

        :param submit_button_text: The submit_button_text of this FormAttributes.  # noqa: E501
        :type: str
        """

        self._submit_button_text = submit_button_text

    @property
    def success_message(self):
        """Gets the success_message of this FormAttributes.  # noqa: E501

        Message displayed to submitter after files are uploaded  # noqa: E501

        :return: The success_message of this FormAttributes.  # noqa: E501
        :rtype: str
        """
        return self._success_message

    @success_message.setter
    def success_message(self, success_message):
        """Sets the success_message of this FormAttributes.

        Message displayed to submitter after files are uploaded  # noqa: E501

        :param success_message: The success_message of this FormAttributes.  # noqa: E501
        :type: str
        """

        self._success_message = success_message

    @property
    def css_styles(self):
        """Gets the css_styles of this FormAttributes.  # noqa: E501

        CSS Styles of the form.  # noqa: E501

        :return: The css_styles of this FormAttributes.  # noqa: E501
        :rtype: str
        """
        return self._css_styles

    @css_styles.setter
    def css_styles(self, css_styles):
        """Sets the css_styles of this FormAttributes.

        CSS Styles of the form.  # noqa: E501

        :param css_styles: The css_styles of this FormAttributes.  # noqa: E501
        :type: str
        """

        self._css_styles = css_styles

    @property
    def elements(self):
        """Gets the elements of this FormAttributes.  # noqa: E501

        Array of form fields defined for the form  # noqa: E501

        :return: The elements of this FormAttributes.  # noqa: E501
        :rtype: list[FormField]
        """
        return self._elements

    @elements.setter
    def elements(self, elements):
        """Sets the elements of this FormAttributes.

        Array of form fields defined for the form  # noqa: E501

        :param elements: The elements of this FormAttributes.  # noqa: E501
        :type: list[FormField]
        """

        self._elements = elements

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(FormAttributes, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FormAttributes):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
